# LaTeX2HTML 2002-2-1 (1.71)
# Associate images original text with physical files.


$key = q/widetilde{F}_M(x,y);MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="71" HEIGHT="42" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img48.png"
 ALT="$\widetilde{F}_M(x,y)$">|; 

$key = q/{displaymath}sigma_n^2=sigma_s^2+N_ssigma_b^2.{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="122" HEIGHT="31" BORDER="0"
 SRC="|."$dir".q|img171.png"
 ALT="\begin{displaymath}
\sigma_n^2 = \sigma_s^2 + N_s \sigma_b^2.
\end{displaymath}">|; 

$key = q/N_R;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="29" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img30.png"
 ALT="$N_R$">|; 

$key = q/displaystyleepsilon^2_k=epsilon_{ik}^2+epsilon_{sk}^2;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="105" HEIGHT="39" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img175.png"
 ALT="$\displaystyle \epsilon^2_k = \epsilon_{ik}^2 + \epsilon_{sk}^2$">|; 

$key = q/A_2;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="25" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img96.png"
 ALT="$A_2$">|; 

$key = q/sigma;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="15" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img62.png"
 ALT="$\sigma$">|; 

$key = q/{displaymath}widetilde{B}={{rm{mode}=3cdot{{rm{median}-2cdot{{rm{mean}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="261" HEIGHT="28" BORDER="0"
 SRC="|."$dir".q|img63.png"
 ALT="\begin{displaymath}
\widetilde{B} = {\rm mode} = 3 \cdot {\rm median} - 2\cdot {\rm mean}
\end{displaymath}">|; 

$key = q/LN_2;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="38" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img38.png"
 ALT="$LN_2$">|; 

$key = q/g(x,y);MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="54" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img46.png"
 ALT="$g(x,y)$">|; 

$key = q/A'=Awidetilde{f};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="70" HEIGHT="44" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img160.png"
 ALT="$A' = A\widetilde{f}$">|; 

$key = q/bar{Z};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="17" HEIGHT="18" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img100.png"
 ALT="$\bar{Z}$">|; 

$key = q/{displaymath}sigma_{{rm{sc}=0.09Ffrac{A^{1.75}}{D^frac{2}{3}sqrt{2t}}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="145" HEIGHT="51" BORDER="0"
 SRC="|."$dir".q|img172.png"
 ALT="\begin{displaymath}
\sigma_{\rm sc} = 0.09 F \frac{A^{1.75}}{D^\frac{2}{3}\sqrt{2t}}
\end{displaymath}">|; 

$key = q/{displaymath}widetilde{Z}={{rm{median}(y_k){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="119" HEIGHT="31" BORDER="0"
 SRC="|."$dir".q|img179.png"
 ALT="\begin{displaymath}
\widetilde{Z}={\rm median}(y_k)
\end{displaymath}">|; 

$key = q/{displaymath}sigma^2=sigma_r^2+A^2(S_d+S_p)=sigma_r^2+A(s-s_b){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="304" HEIGHT="32" BORDER="0"
 SRC="|."$dir".q|img141.png"
 ALT="\begin{displaymath}
\sigma^2 = \sigma_r^2 + A^2 (S_d + S_p) = \sigma_r^2 + A(s - s_b)
\end{displaymath}">|; 

$key = q/includegraphics[width=textwidth]{aucyg-wres-std};LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="523" HEIGHT="380" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img118.png"
 ALT="\includegraphics[width=\textwidth]{aucyg-wres-std}">|; 

$key = q/L;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="16" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img40.png"
 ALT="$L$">|; 

$key = q/t_{{rm{dark};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="38" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img33.png"
 ALT="$t_{\rm dark}$">|; 

$key = q/{displaymath}f(x,y)=B(x,y)+t_{{rm{flat}D(x,y)+t_{{rm{flat}G(x,y)L+{{rm{noise}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="403" HEIGHT="31" BORDER="0"
 SRC="|."$dir".q|img39.png"
 ALT="\begin{displaymath}
f(x,y)=B(x,y)+t_{\rm flat}D(x,y)+t_{\rm flat}G(x,y)L+{\rm noise}
\end{displaymath}">|; 

$key = q/{displaymath}rho_k=y_k-widetilde{Z}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="92" HEIGHT="30" BORDER="0"
 SRC="|."$dir".q|img180.png"
 ALT="\begin{displaymath}
\rho_k=y_k - \widetilde{Z}
\end{displaymath}">|; 

$key = q/sigma_r'=sqrt{2sigma_r^2+2A^2S_d};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="157" HEIGHT="39" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img148.png"
 ALT="$\sigma_r' = \sqrt{2\sigma_r^2 + 2 A^2 S_d}$">|; 

$key = q/{displaymath}sigma_{{rm{ds}^2=left(sqrt{2sigma_r^2+2A^2S_d}right)^2+A^2S_p{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="248" HEIGHT="48" BORDER="0"
 SRC="|."$dir".q|img147.png"
 ALT="\begin{displaymath}
\sigma_{\rm ds}^2 = \left(\sqrt{2\sigma_r^2 + 2 A^2 S_d}\right)^2 + A^2 S_p
\end{displaymath}">|; 

$key = q/f;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="15" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img153.png"
 ALT="$f$">|; 

$key = q/y;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="14" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img2.png"
 ALT="$y$">|; 

$key = q/{displaymath}k_V=k_V+theta{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="93" HEIGHT="29" BORDER="0"
 SRC="|."$dir".q|img81.png"
 ALT="\begin{displaymath}
k_V = k_V + \theta
\end{displaymath}">|; 

$key = q/sec(z);MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="49" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img89.png"
 ALT="$\sec(z)$">|; 

$key = q/sigma_r;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="22" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img142.png"
 ALT="$\sigma_r$">|; 

$key = q/{displaymath}frac{widetilde{F}_M(x,y)}{bar{F}}=g(x,y){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="139" HEIGHT="47" BORDER="0"
 SRC="|."$dir".q|img51.png"
 ALT="\begin{displaymath}
\frac{\widetilde{F}_M(x,y)}{\bar{F}}=g(x,y)
\end{displaymath}">|; 

$key = q/S_d;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="23" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img139.png"
 ALT="$S_d$">|; 

$key = q/{displaymath}M_j=m_j+Z_k+k_M(C_1^M-C_2^M){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="247" HEIGHT="32" BORDER="0"
 SRC="|."$dir".q|img85.png"
 ALT="\begin{displaymath}
M_j = m_j + Z_k + k_M(C_1^M - C_2^M)\\\\
\end{displaymath}">|; 

$key = q/E;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="18" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img92.png"
 ALT="$E$">|; 

$key = q/C_1^M;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="33" HEIGHT="39" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img86.png"
 ALT="$C_1^M$">|; 

$key = q/{displaymath}Z=bar{Z}+E(A-bar{A}){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="143" HEIGHT="31" BORDER="0"
 SRC="|."$dir".q|img98.png"
 ALT="\begin{displaymath}
Z = \bar{Z} + E (A - \bar{A})
\end{displaymath}">|; 

$key = q/{displaymath}widetilde{D}(x,y)=frac{d(x,y)-widetilde{B}(x,y)}{t_{{rm{dark}}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="206" HEIGHT="50" BORDER="0"
 SRC="|."$dir".q|img21.png"
 ALT="\begin{displaymath}
\widetilde{D}(x,y) = \frac{d(x,y) - \widetilde{B}(x,y)}{t_{\rm dark}}
\end{displaymath}">|; 

$key = q/{displaymath}bar{F}=sum_xsum_yt_{{rm{flat}bar{G}g(x,y)L=t_{{rm{flat}bar{G}Lsum_xsum_yg(x,y)=t_{{rm{flat}bar{G}L{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="445" HEIGHT="49" BORDER="0"
 SRC="|."$dir".q|img49.png"
 ALT="\begin{displaymath}
\bar{F}=\sum_x\sum_yt_{\rm flat}\bar{G}g(x,y)L=t_{\rm flat}\bar{G}L\sum_x\sum_yg(x,y)=
t_{\rm flat}\bar{G}L
\end{displaymath}">|; 

$key = q/{displaymath}F=sum_iI_i-Nwidetilde{B}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="127" HEIGHT="48" BORDER="0"
 SRC="|."$dir".q|img59.png"
 ALT="\begin{displaymath}
F = \sum_i I_i - N \widetilde{B}
\end{displaymath}">|; 

$key = q/widetilde{s_b};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="19" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img163.png"
 ALT="$\widetilde{s_b}$">|; 

$key = q/bar{F};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="18" HEIGHT="18" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img50.png"
 ALT="$\bar{F}$">|; 

$key = q/{displaymath}frac{bar{F}}{widetilde{F}_M(x,y)}[s(x,y)-widetilde{D}_M(x,y)]=t_{{rm{data}bar{G}I(x,y)+{{rm{noise}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="396" HEIGHT="51" BORDER="0"
 SRC="|."$dir".q|img53.png"
 ALT="\begin{displaymath}
\frac{\bar{F}}{\widetilde{F}_M(x,y)}[s(x,y) - \widetilde{D}_M(x,y)] =
t_{\rm data} \bar{G} I(x,y) + {\rm noise}
\end{displaymath}">|; 

$key = q/pm2;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="27" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img120.png"
 ALT="$\pm2$">|; 

$key = q/{displaymath}rho'_k=(y_k-widetilde{Z})sqrt{W_k}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="146" HEIGHT="31" BORDER="0"
 SRC="|."$dir".q|img181.png"
 ALT="\begin{displaymath}
\rho'_k=(y_k - \widetilde{Z})\sqrt{W_k}
\end{displaymath}">|; 

$key = q/t=0;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="43" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img14.png"
 ALT="$t = 0$">|; 

$key = q/{displaymath}{{rm{me1}^2=frac{sumrho_k^2W'_k}{N-1}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="126" HEIGHT="46" BORDER="0"
 SRC="|."$dir".q|img187.png"
 ALT="\begin{displaymath}
{\rm me1}^2 = \frac{\sum\rho_k^2W'_k}{N-1}
\end{displaymath}">|; 

$key = q/b;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="12" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img17.png"
 ALT="$b$">|; 

$key = q/includegraphics[width=textwidth]{zp-am-1};LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="537" HEIGHT="375" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img125.png"
 ALT="\includegraphics[width=\textwidth]{zp-am-1}">|; 

$key = q/{displaymath}widetilde{F}_M(x,y)=frac{1}{N}sum_if'(x,y)=frac{1}{N}sum_if(x,y)-D_M^F(x,y){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="406" HEIGHT="51" BORDER="0"
 SRC="|."$dir".q|img43.png"
 ALT="\begin{displaymath}
\widetilde{F}_M(x,y) = \frac{1}{N}\sum_i f'(x,y) = \frac{1}{N}\sum_i f(x,y)-D_M^F(x,y)
\end{displaymath}">|; 

$key = q/backslash;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="13" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img66.png"
 ALT="$\backslash$">|; 

$key = q/V_j;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="22" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img75.png"
 ALT="$V_j$">|; 

$key = q/r;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="13" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img103.png"
 ALT="$r$">|; 

$key = q/{displaymath}sigma_d^2=sigma_r^2+A^2S_d{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="118" HEIGHT="31" BORDER="0"
 SRC="|."$dir".q|img144.png"
 ALT="\begin{displaymath}
\sigma_d^2 = \sigma_r^2 + A^2 S_d
\end{displaymath}">|; 

$key = q/epsilon_i;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="17" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img176.png"
 ALT="$\epsilon_i$">|; 

$key = q/includegraphics[width=textwidth]{zp-am-2};LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="537" HEIGHT="375" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img127.png"
 ALT="\includegraphics[width=\textwidth]{zp-am-2}">|; 

$key = q/kappa;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="14" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img61.png"
 ALT="$\kappa$">|; 

$key = q/A_M;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="33" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img102.png"
 ALT="$A_M$">|; 

$key = q/{displaymath}V_j=v_j+Z_k+k_V(B_j-V_j){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="208" HEIGHT="32" BORDER="0"
 SRC="|."$dir".q|img71.png"
 ALT="\begin{displaymath}
V_j = v_j + Z_k + k_V(B_j-V_j)
\end{displaymath}">|; 

$key = q/includegraphics[width=textwidth]{zp-t-1};LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="536" HEIGHT="377" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img126.png"
 ALT="\includegraphics[width=\textwidth]{zp-t-1}">|; 

$key = q/{displaymath}frac{A_M+A_m}{2}-frac{r}{2}(A_M-A_m){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="198" HEIGHT="42" BORDER="0"
 SRC="|."$dir".q|img104.png"
 ALT="\begin{displaymath}
\frac{A_M + A_m}{2} - \frac{r}{2}(A_M - A_m)
\end{displaymath}">|; 

$key = q/B(x,y);MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="59" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img5.png"
 ALT="$B(x,y)$">|; 

$key = q/{displaymath}frac{A_M+A_m}{2}+frac{r}{2}(A_M+A_m){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="199" HEIGHT="42" BORDER="0"
 SRC="|."$dir".q|img105.png"
 ALT="\begin{displaymath}
\frac{A_M + A_m}{2} + \frac{r}{2}(A_M + A_m)
\end{displaymath}">|; 

$key = q/{displaymath}s(x,y)=B(x,y)+t_{data}D(x,y)+t_{{rm{data}bar{G}g(x,y)I(x,y))+{{rm{noise}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="468" HEIGHT="31" BORDER="0"
 SRC="|."$dir".q|img52.png"
 ALT="\begin{displaymath}
s(x,y) = B(x,y) + t_{data} D(x,y) + t_{\rm data} \bar{G} g(x, y) I(x, y)) + {\rm noise}
\end{displaymath}">|; 

$key = q/displaystyley_k=S_k-I_k;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="100" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img174.png"
 ALT="$\displaystyle y_k = S_k - I_k$">|; 

$key = q/includegraphics[width=textwidth]{v-res-mag-zponly};LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="523" HEIGHT="380" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img116.png"
 ALT="\includegraphics[width=\textwidth]{v-res-mag-zponly}">|; 

$key = q/widetilde{D}_M;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="34" HEIGHT="42" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img25.png"
 ALT="$\widetilde{D}_M$">|; 

$key = q/displaystyleB;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="18" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img106.png"
 ALT="$\displaystyle B$">|; 

$key = q/D;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="19" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img11.png"
 ALT="$D$">|; 

$key = q/{displaymath}s=s_b+A(S_d+S_p){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="150" HEIGHT="32" BORDER="0"
 SRC="|."$dir".q|img137.png"
 ALT="\begin{displaymath}
s = s_b + A ( S_d + S_p)
\end{displaymath}">|; 

$key = q/displaystylev+Z_V+k_V(B-V);MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="163" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img110.png"
 ALT="$\displaystyle v+Z_V+k_V(B-V)$">|; 

$key = q/displaystyler+Z_R+k_R(V-R);MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="161" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img112.png"
 ALT="$\displaystyle r+Z_R+k_R(V-R)$">|; 

$key = q/{displaymath}widetilde{Z}=widetilde{Z}+sum_k(y_k-widetilde{Z})W'_k{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="181" HEIGHT="48" BORDER="0"
 SRC="|."$dir".q|img185.png"
 ALT="\begin{displaymath}
\widetilde{Z}=\widetilde{Z} + \sum_k(y_k-\widetilde{Z})W'_k
\end{displaymath}">|; 

$key = q/S;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="16" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img135.png"
 ALT="$S$">|; 

$key = q/{displaymath}F_T=sum_iI_i{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="82" HEIGHT="48" BORDER="0"
 SRC="|."$dir".q|img58.png"
 ALT="\begin{displaymath}
F_T = \sum_i I_i
\end{displaymath}">|; 

$key = q/{displaymath}sigma_{{rm{dark}=sqrt{S_{{rm{dark}}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="113" HEIGHT="30" BORDER="0"
 SRC="|."$dir".q|img132.png"
 ALT="\begin{displaymath}
\sigma_{\rm dark} = \sqrt{S_{\rm dark}}
\end{displaymath}">|; 

$key = q/v;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="13" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img69.png"
 ALT="$v$">|; 

$key = q/{displaymath}widetilde{D}_M(x,y)=frac{1}{M}sum_id_i(x,y){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="198" HEIGHT="51" BORDER="0"
 SRC="|."$dir".q|img36.png"
 ALT="\begin{displaymath}
\widetilde{D}_M(x,y) = \frac{1}{M}\sum_i d_i(x,y)
\end{displaymath}">|; 

$key = q/1;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="13" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img35.png"
 ALT="$1$">|; 

$key = q/Z_k;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="24" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img78.png"
 ALT="$Z_k$">|; 

$key = q/{displaymath}widetilde{D}'(x,y)=t_{{rm{dark}widetilde{D}(x,y)=frac{1}{M}sum_id_i(x,y)-widetilde{B}(x,y){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="375" HEIGHT="51" BORDER="0"
 SRC="|."$dir".q|img23.png"
 ALT="\begin{displaymath}
\widetilde{D}'(x,y)=t_{\rm dark}\widetilde{D}(x,y)=\frac{1}{M}\sum_i d_i(x,y) - \widetilde{B}(x,y)
\end{displaymath}">|; 

$key = q/displaystyleV;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="18" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img109.png"
 ALT="$\displaystyle V$">|; 

$key = q/sigma_fslashwidetilde{f};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="43" HEIGHT="44" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img162.png"
 ALT="$\sigma_f/\widetilde{f}$">|; 

$key = q/{displaymath}Z_k=Z_k+thetafrac{sum_j(B_j-V_j)W'_j}{sum_jW'_j}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="214" HEIGHT="53" BORDER="0"
 SRC="|."$dir".q|img82.png"
 ALT="\begin{displaymath}
Z_k = Z_k + \theta\frac{\sum_j(B_j-V_j) W'_j}{\sum_jW'_j}
\end{displaymath}">|; 

$key = q/{displaymath}rho_j=y_j-widetilde{Z_k}-k_V(B_j-V_j){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="209" HEIGHT="32" BORDER="0"
 SRC="|."$dir".q|img79.png"
 ALT="\begin{displaymath}
\rho_j=y_j - \widetilde{Z_k} - k_V (B_j - V_j)
\end{displaymath}">|; 

$key = q/pm30;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="35" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img119.png"
 ALT="$\pm30$">|; 

$key = q/kappasigma;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="25" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img57.png"
 ALT="$\kappa\sigma$">|; 

$key = q/{displaymath}widetilde{D}(x,y)=frac{1}{t_{{rm{dark}}frac{1}{M}sum_id_i(x,y)-widetilde{B}(x,y){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="296" HEIGHT="51" BORDER="0"
 SRC="|."$dir".q|img22.png"
 ALT="\begin{displaymath}
\widetilde{D}(x,y) = \frac{1}{t_{\rm dark}}\frac{1}{M}\sum_i d_i(x,y) - \widetilde{B}(x,y)
\end{displaymath}">|; 

$key = q/{displaymath}sigma_{{rm{ds}^2=sigma_r'^2+As_{{rm{ds}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="123" HEIGHT="31" BORDER="0"
 SRC="|."$dir".q|img151.png"
 ALT="\begin{displaymath}
\sigma_{\rm ds}^2 = \sigma_r'^2 + As_{\rm ds}
\end{displaymath}">|; 

$key = q/B-V=0.5;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="99" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img124.png"
 ALT="$B-V=0.5$">|; 

$key = q/{displaymath}f'(x,y)=f(x,y)-D_M^F(x,y)=t_{{rm{flat}G(x,y)L+{{rm{noise}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="394" HEIGHT="31" BORDER="0"
 SRC="|."$dir".q|img42.png"
 ALT="\begin{displaymath}
f'(x,y)=f(x,y)-D_M^F(x,y)=t_{\rm flat}G(x,y)L+{\rm noise}
\end{displaymath}">|; 

$key = q/A;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="17" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img136.png"
 ALT="$A$">|; 

$key = q/widetilde{B};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="18" HEIGHT="20" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img27.png"
 ALT="$\widetilde{B}$">|; 

$key = q/s_b;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="19" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img138.png"
 ALT="$s_b$">|; 

$key = q/Z_0;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="24" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img94.png"
 ALT="$Z_0$">|; 

$key = q/widetilde{D};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="19" HEIGHT="20" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img28.png"
 ALT="$\widetilde{D}$">|; 

$key = q/includegraphics[width=textwidth]{v-se-color};LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="497" HEIGHT="375" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img122.png"
 ALT="\includegraphics[width=\textwidth]{v-se-color}">|; 

$key = q/B-V=2.0;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="99" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img123.png"
 ALT="$B-V=2.0$">|; 

$key = q/{displaymath}Z_2=Z_1-E(A_2-A_1){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="170" HEIGHT="31" BORDER="0"
 SRC="|."$dir".q|img97.png"
 ALT="\begin{displaymath}
Z_2 = Z_1 - E(A_2-A_1)
\end{displaymath}">|; 

$key = q/>;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="18" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img65.png"
 ALT="$&gt;$">|; 

$key = q/<;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="18" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img64.png"
 ALT="$&lt;$">|; 

$key = q/{displaymath}b(x,y)=B(x,y)+{{rm{noise}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="183" HEIGHT="31" BORDER="0"
 SRC="|."$dir".q|img16.png"
 ALT="\begin{displaymath}
b(x,y) = B(x,y) + {\rm noise}
\end{displaymath}">|; 

$key = q/{displaymath}s_{{rm{ds}=AS_p{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="74" HEIGHT="32" BORDER="0"
 SRC="|."$dir".q|img146.png"
 ALT="\begin{displaymath}
s_{\rm ds} = AS_p
\end{displaymath}">|; 

$key = q/{displaymath}sigma_{DB}=N_Rsqrt{frac{1}{N}+frac{1}{M}left(frac{t_{{rm{data}}{t_{{rm{dark}}right)^2}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="232" HEIGHT="55" BORDER="0"
 SRC="|."$dir".q|img29.png"
 ALT="\begin{displaymath}
\sigma_{DB} = N_R\sqrt{\frac{1}{N}+\frac{1}{M}
\left(\frac{t_{\rm data}}{t_{\rm dark}}\right)^2}
\end{displaymath}">|; 

$key = q/{displaymath}sigma_{{rm{shot}=sqrt{S_{{rm{ph}+S_{{rm{dark}}=sqrt{S}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="209" HEIGHT="36" BORDER="0"
 SRC="|."$dir".q|img134.png"
 ALT="\begin{displaymath}
\sigma_{\rm shot} = \sqrt{S_{\rm ph} + S_{\rm dark}} = \sqrt{S}
\end{displaymath}">|; 

$key = q/widetilde{f}=1;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="47" HEIGHT="42" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img161.png"
 ALT="$\widetilde{f} = 1$">|; 

$key = q/{displaymath}widetilde{D}_M(x,y)=widetilde{B}(x,y)+t_{{rm{data}widetilde{D}(x,y)ac{t_{{rm{data}}{t_{{rm{dark}}widetilde{D}'(x,y){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="452" HEIGHT="44" BORDER="0"
 SRC="|."$dir".q|img26.png"
 ALT="\begin{displaymath}
\widetilde{D}_M(x,y)
=\widetilde{B}(x,y) + t_{\rm data}\wide...
...e{B}(x,y)+\frac{t_{\rm data}}{t_{\rm dark}}\widetilde{D}'(x,y)
\end{displaymath}">|; 

$key = q/A_m;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="30" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img101.png"
 ALT="$A_m$">|; 

$key = q/widetilde{f};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="16" HEIGHT="44" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img158.png"
 ALT="$\widetilde{f}$">|; 

$key = q/beta;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="15" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img184.png"
 ALT="$\beta$">|; 

$key = q/(B-V);MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="67" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img83.png"
 ALT="$(B-V)$">|; 

$key = q/{displaymath}n^2(s)=sigma^2=sigma_r^2+A|(s-widetilde{s_b})|+left(frac{sigma_f}{widetilde{f}}right)^2(s-widetilde{s_b})^2{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="367" HEIGHT="58" BORDER="0"
 SRC="|."$dir".q|img165.png"
 ALT="\begin{displaymath}
n^2(s) = \sigma^2 = \sigma_r^2 + A \vert(s-\widetilde{s_b})\...
...t(\frac{\sigma_f}{\widetilde{f}}\right)^2(s-\widetilde{s_b})^2
\end{displaymath}">|; 

$key = q/1slashf;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="32" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img131.png"
 ALT="$1/f$">|; 

$key = q/displaystyleb+Z_B+k_B(B-V);MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="162" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img108.png"
 ALT="$\displaystyle b+Z_B+k_B(B-V)$">|; 

$key = q/{displaymath}sigma_b^2=frac{1}{N_b}sum_{i=1}^{N_b}n^2(s_i){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="137" HEIGHT="59" BORDER="0"
 SRC="|."$dir".q|img168.png"
 ALT="\begin{displaymath}
\sigma_b^2 = \frac{1}{N_b}\sum_{i=1}^{N_b}n^2(s_i)
\end{displaymath}">|; 

$key = q/v_j;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="20" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img77.png"
 ALT="$v_j$">|; 

$key = q/bar{A};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="17" HEIGHT="18" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img99.png"
 ALT="$\bar{A}$">|; 

$key = q/textstyle=;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="18" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img107.png"
 ALT="$\textstyle =$">|; 

$key = q/alpha;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="16" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img183.png"
 ALT="$\alpha$">|; 

$key = q/{displaymath}W'_k=frac{W_k}{1+left({rho'_k}over{alpha}right)^beta}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="125" HEIGHT="62" BORDER="0"
 SRC="|."$dir".q|img182.png"
 ALT="\begin{displaymath}
W'_k = \frac{W_k}{1 + \left({\rho'_k}\over{\alpha}\right)^\beta}
\end{displaymath}">|; 

$key = q/{displaymath}theta=frac{sum_jrho_j(B_j-V_j)W'_j}{sum_j(B_j-V_j)^2W'_j}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="172" HEIGHT="53" BORDER="0"
 SRC="|."$dir".q|img80.png"
 ALT="\begin{displaymath}
\theta = \frac{\sum_j\rho_j(B_j-V_j) W'_j}{\sum_j(B_j-V_j)^2 W'_j}
\end{displaymath}">|; 

$key = q/D(x,y);MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="60" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img7.png"
 ALT="$D(x,y)$">|; 

$key = q/S_p;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="23" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img140.png"
 ALT="$S_p$">|; 

$key = q/{displaymath}widetilde{B}(x,y)=frac{1}{N}sum_ib_i(x,y){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="178" HEIGHT="51" BORDER="0"
 SRC="|."$dir".q|img19.png"
 ALT="\begin{displaymath}
\widetilde{B}(x,y) = \frac{1}{N}\sum_i b_i(x,y)
\end{displaymath}">|; 

$key = q/bar{G}t_{{rm{data};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="51" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img56.png"
 ALT="$\bar{G}t_{\rm data}$">|; 

$key = q/{displaymath}widetilde{B}(x,y)=b(x,y){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="124" HEIGHT="31" BORDER="0"
 SRC="|."$dir".q|img18.png"
 ALT="\begin{displaymath}
\widetilde{B}(x,y) = b(x,y)
\end{displaymath}">|; 

$key = q/includegraphics[width=textwidth]{aucyg-res-std};LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="524" HEIGHT="380" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img117.png"
 ALT="\includegraphics[width=\textwidth]{aucyg-res-std}">|; 

$key = q/{displaymath}sigma_{D}=N_Rsqrt{frac{1}{M}}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="108" HEIGHT="45" BORDER="0"
 SRC="|."$dir".q|img37.png"
 ALT="\begin{displaymath}
\sigma_{D} = N_R\sqrt{\frac{1}{M}}
\end{displaymath}">|; 

$key = q/pm10%;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="50" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img3.png"
 ALT="$\pm 10\%$">|; 

$key = q/F;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="18" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img44.png"
 ALT="$F$">|; 

$key = q/k;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="14" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img73.png"
 ALT="$k$">|; 

$key = q/displaystyleI;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="13" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img113.png"
 ALT="$\displaystyle I$">|; 

$key = q/{displaymath}sigma_{{rm{shot}=sqrt{sigma_{{rm{ph}^2+sigma_{{rm{dark}^2}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="159" HEIGHT="36" BORDER="0"
 SRC="|."$dir".q|img133.png"
 ALT="\begin{displaymath}
\sigma_{\rm shot} = \sqrt{\sigma_{\rm ph}^2 + \sigma_{\rm dark}^2}
\end{displaymath}">|; 

$key = q/I(x,y);MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="54" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img9.png"
 ALT="$I(x,y)$">|; 

$key = q/D_M^F(x,y);MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="74" HEIGHT="39" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img41.png"
 ALT="$D_M^F(x,y)$">|; 

$key = q/{displaymath}epsilon_i=2.51188logleft(1+frac{sqrt{sigma_n^2+sigma_{{rm{sc}^2}}{F}right).{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="264" HEIGHT="54" BORDER="0"
 SRC="|."$dir".q|img173.png"
 ALT="\begin{displaymath}
\epsilon_i = 2.51188 \log\left(1 + \frac{\sqrt{\sigma_n^2 + \sigma_{\rm sc}^2}}{F}\right).
\end{displaymath}">|; 

$key = q/A_1;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="25" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img95.png"
 ALT="$A_1$">|; 

$key = q/N_s;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="25" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img169.png"
 ALT="$N_s$">|; 

$key = q/{displaymath}epsilon_{{rm{zp}^2=frac{sumrho_k^2W'_k}{sumW'_k}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="107" HEIGHT="50" BORDER="0"
 SRC="|."$dir".q|img186.png"
 ALT="\begin{displaymath}
\epsilon_{\rm zp}^2 = \frac{\sum\rho_k^2W'_k}{\sum W'_k}
\end{displaymath}">|; 

$key = q/displaystyles=sec(z)-1;;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="115" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img90.png"
 ALT="$\displaystyle s = \sec(z) - 1;$">|; 

$key = q/includegraphics[width=textwidth]{v-se-color-zponly};LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="497" HEIGHT="375" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img121.png"
 ALT="\includegraphics[width=\textwidth]{v-se-color-zponly}">|; 

$key = q/{displaymath}widetilde{I}(x,y)=frac{1}{bar{G}cdott_{{rm{data}}frac{bar{F}}{widetilde{F}_M(x,y)}[s(x,y)-widetilde{D}_M(x,y)]{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="354" HEIGHT="51" BORDER="0"
 SRC="|."$dir".q|img54.png"
 ALT="\begin{displaymath}
\widetilde{I}(x,y) = \frac{1}{\bar{G}\cdot t_{\rm data}}\frac{\bar{F}}{\widetilde{F}_M(x,y)}
[s(x,y) - \widetilde{D}_M(x,y)]
\end{displaymath}">|; 

$key = q/{displaymath}M_I=-2.511886logleft(sum_iI_i-Nwidetilde{B}right){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="268" HEIGHT="56" BORDER="0"
 SRC="|."$dir".q|img60.png"
 ALT="\begin{displaymath}
M_I = -2.511886\log\left(\sum_i I_i - N \widetilde{B}\right)
\end{displaymath}">|; 

$key = q/s_i;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="18" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img167.png"
 ALT="$s_i$">|; 

$key = q/displaystyleR;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="18" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img111.png"
 ALT="$\displaystyle R$">|; 

$key = q/displaystylei+Z_I+k_I(V-I);MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="147" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img114.png"
 ALT="$\displaystyle i+Z_I+k_I(V-I)$">|; 

$key = q/V;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="18" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img68.png"
 ALT="$V$">|; 

$key = q/{displaymath}sigma_{{rm{ff}^2=f^2sigma_r'^2+Afs_{{rm{ff}+left(sigma_fs_{{rm{ff}right)^2{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="222" HEIGHT="32" BORDER="0"
 SRC="|."$dir".q|img157.png"
 ALT="\begin{displaymath}
\sigma_{\rm ff}^2 = f^2 \sigma_r'^2 + A f s_{\rm ff} + \left(\sigma_f s_{\rm ff}\right)^2
\end{displaymath}">|; 

$key = q/epsilon_s;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="18" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img177.png"
 ALT="$\epsilon_s$">|; 

$key = q/{displaymath}sigma_{{rm{ph}=sqrt{S_{{rm{ph}}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="91" HEIGHT="36" BORDER="0"
 SRC="|."$dir".q|img129.png"
 ALT="\begin{displaymath}
\sigma_{\rm ph} = \sqrt{S_{\rm ph}}
\end{displaymath}">|; 

$key = q/{displaymath}Z(A)=Z_0-EA{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="130" HEIGHT="31" BORDER="0"
 SRC="|."$dir".q|img93.png"
 ALT="\begin{displaymath}
Z(A) = Z_0 - EA
\end{displaymath}">|; 

$key = q/displaystyleA=1+s[0.9981833-s(0.002875+0.0008083s)];MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="376" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img91.png"
 ALT="$\displaystyle A=1 + s[0.9981833 - s(0.002875+0.0008083 s)]$">|; 

$key = q/{displaymath}widetilde{I}(x,y)=frac{1}{bar{G}cdott_{{rm{data}}frac{bar{F}}{widet{{rm{dark}}widetilde{D}'(x,y)-widetilde{B}(x,y)]{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="457" HEIGHT="51" BORDER="0"
 SRC="|."$dir".q|img55.png"
 ALT="\begin{displaymath}
\widetilde{I}(x,y) = \frac{1}{\bar{G}\cdot t_{\rm data}}\fra...
... data}}{t_{\rm dark}}\widetilde{D}'(x,y) - \widetilde{B}(x,y)]
\end{displaymath}">|; 

$key = q/s_{{rm{ds};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="26" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img152.png"
 ALT="$s_{\rm ds}$">|; 

$key = q/I;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="13" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img13.png"
 ALT="$I$">|; 

$key = q/M;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="23" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img32.png"
 ALT="$M$">|; 

$key = q/{displaymath}sigma_{{rm{ds}^2=2sigma_r^2+A^2(2S_d+S_p){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="193" HEIGHT="32" BORDER="0"
 SRC="|."$dir".q|img145.png"
 ALT="\begin{displaymath}
\sigma_{\rm ds}^2 = 2\sigma_r^2 + A^2 (2 S_d + S_p)
\end{displaymath}">|; 

$key = q/I(x,y)=0;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="86" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img15.png"
 ALT="$I(x,y)=0$">|; 

$key = q/C_2^M;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="33" HEIGHT="39" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img87.png"
 ALT="$C_2^M$">|; 

$key = q/N_b;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="25" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img166.png"
 ALT="$N_b$">|; 

$key = q/x;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="14" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img1.png"
 ALT="$x$">|; 

$key = q/sigma_r''=widetilde{f}sigma_r';MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="74" HEIGHT="42" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img159.png"
 ALT="$\sigma_r'' =
\widetilde{f}\sigma_r'$">|; 

$key = q/G(x,y);MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="58" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img8.png"
 ALT="$G(x,y)$">|; 

$key = q/n(s);MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="37" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img164.png"
 ALT="$n(s)$">|; 

$key = q/{displaymath}s(x,y)=B(x,y)+tD(x,y)+tG(x,y)I(x,y)+{{rm{noise}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="398" HEIGHT="31" BORDER="0"
 SRC="|."$dir".q|img4.png"
 ALT="\begin{displaymath}
s(x,y) = B(x,y) + t D(x,y) + t G(x, y) I(x, y) + {\rm noise}
\end{displaymath}">|; 

$key = q/{displaymath}sigma_s^2=sum_{i=1}^{N_s}n^2(s_i){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="109" HEIGHT="58" BORDER="0"
 SRC="|."$dir".q|img170.png"
 ALT="\begin{displaymath}
\sigma_s^2 = \sum_{i=1}^{N_s}n^2(s_i)
\end{displaymath}">|; 

$key = q/t;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="11" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img6.png"
 ALT="$t$">|; 

$key = q/sqrt{2};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="28" HEIGHT="40" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img143.png"
 ALT="$\sqrt{2}$">|; 

$key = q/B_j;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="25" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img74.png"
 ALT="$B_j$">|; 

$key = q/B;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="18" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img10.png"
 ALT="$B$">|; 

$key = q/S_{{rm{ph};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="31" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img130.png"
 ALT="$S_{\rm ph}$">|; 

$key = q/{displaymath}G(x,y)=bar{G}g(x,y){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="138" HEIGHT="31" BORDER="0"
 SRC="|."$dir".q|img45.png"
 ALT="\begin{displaymath}
G(x,y)=\bar{G}g(x,y)
\end{displaymath}">|; 

$key = q/{displaymath}widetilde{F}_M(x,y)=t_{{rm{flat}bar{G}g(x,y)L{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="191" HEIGHT="31" BORDER="0"
 SRC="|."$dir".q|img47.png"
 ALT="\begin{displaymath}
\widetilde{F}_M(x,y)=t_{\rm flat}\bar{G}g(x,y)L
\end{displaymath}">|; 

$key = q/{displaymath}B_j=b_j+Z_k+k_B(B_j-V_j){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="212" HEIGHT="32" BORDER="0"
 SRC="|."$dir".q|img70.png"
 ALT="\begin{displaymath}
B_j = b_j + Z_k + k_B(B_j-V_j)
\end{displaymath}">|; 

$key = q/15^{{rm{th};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="35" HEIGHT="18" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img67.png"
 ALT="$15^{\rm th}$">|; 

$key = q/t_{{rm{data};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="38" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img24.png"
 ALT="$t_{\rm data}$">|; 

$key = q/k_M;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="29" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img88.png"
 ALT="$k_M$">|; 

$key = q/includegraphics[width=textwidth]{zp-t-2};LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="536" HEIGHT="377" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img128.png"
 ALT="\includegraphics[width=\textwidth]{zp-t-2}">|; 

$key = q/G;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="18" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img12.png"
 ALT="$G$">|; 

$key = q/{displaymath}W_k=frac{1}{epsilon_k^2}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="64" HEIGHT="47" BORDER="0"
 SRC="|."$dir".q|img178.png"
 ALT="\begin{displaymath}
W_k = \frac{1}{\epsilon_k^2}
\end{displaymath}">|; 

$key = q/b_j;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="19" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img76.png"
 ALT="$b_j$">|; 

$key = q/j;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="13" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img72.png"
 ALT="$j$">|; 

$key = q/R;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="18" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img84.png"
 ALT="$R$">|; 

$key = q/{displaymath}sigma_{{rm{ds}^2=sigma_r'^2+A^2S_p{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="127" HEIGHT="32" BORDER="0"
 SRC="|."$dir".q|img149.png"
 ALT="\begin{displaymath}
\sigma_{\rm ds}^2 = \sigma_r'^2 + A^2 S_p
\end{displaymath}">|; 

$key = q/displaystylev+Z_V+k_V(V-I);MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="158" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img115.png"
 ALT="$\displaystyle v+Z_V+k_V(V-I)$">|; 

$key = q/1slash3;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="30" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img34.png"
 ALT="$1/3$">|; 

$key = q/{displaymath}s_{{rm{ff}=frac{1}{f}AS_p{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="85" HEIGHT="45" BORDER="0"
 SRC="|."$dir".q|img155.png"
 ALT="\begin{displaymath}
s_{\rm ff} = \frac{1}{f}AS_p
\end{displaymath}">|; 

$key = q/sigma_f;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="23" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img154.png"
 ALT="$\sigma_f$">|; 

$key = q/sigma_r';MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="22" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img150.png"
 ALT="$\sigma_r'$">|; 

$key = q/N;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="20" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img31.png"
 ALT="$N$">|; 

$key = q/{displaymath}d(x,y)=B(x,y)+tD(x,y)+{{rm{noise}{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="268" HEIGHT="31" BORDER="0"
 SRC="|."$dir".q|img20.png"
 ALT="\begin{displaymath}
d(x,y) = B(x,y)+tD(x,y)+{\rm noise}
\end{displaymath}">|; 

$key = q/{displaymath}sigma_{{rm{ff}^2=fsigma_r'^2+A^2S_p+left(frac{sigma_f}{f}AS_pright)^2{displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="239" HEIGHT="49" BORDER="0"
 SRC="|."$dir".q|img156.png"
 ALT="\begin{displaymath}
\sigma_{\rm ff}^2 = f \sigma_r'^2 + A^2 S_p + \left(\frac{\sigma_f}{f}AS_p\right)^2
\end{displaymath}">|; 

1;

